﻿using NUnit.Framework;
using OpenQA.Selenium;
using OpenQA.Selenium.Chrome;
using OpenQA.Selenium.Support.PageObjects;
using OpenQA.Selenium.Support.UI;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using WebDriverDemo.Facades;
using WebDriverDemo.Models;
using WebDriverDemo.Pages;

namespace WebDriverDemo
{
    public class RegistrationTests
    {
        private IWebDriver driver;

        [SetUp]
        public void Initialize()
        {
            this.driver = new ChromeDriver();
        }

        [TearDown]
        public void EndTests()
        {
            driver.Quit();
        }
        
        [Test]
        public void NavigateToRegistrationPage()
        {
            var homePage = new HomePage();
            PageFactory.InitElements(this.driver, homePage);
            var registrationPage = new RegistrationPage();
            PageFactory.InitElements(this.driver, registrationPage);

            homePage.Navigate();
            homePage.RegistrationButton.Click();

            Assert.AreEqual("Registration | Demoqa", registrationPage.Title);
        }

        public void RegistrationWithFullDate()
        {
            var registrationPage = new RegistrationPage();
            PageFactory.InitElements(this.driver, registrationPage);
            var registrationFacade = new RegistrationFacade();
            var user = new RegistrationUser();

            registrationFacade.RegistrateUser(registrationPage, user, this.driver);

            Assert.AreEqual("Thank you for your registration", registrationPage.RegistrationCompleteMessage.Text);
        }

        public void RegistrationWithoutFirstName()
        {
            var registrationPage = new RegistrationPage();
            PageFactory.InitElements(this.driver, registrationPage);
            var registrationFacade = new RegistrationFacade();
            var user = new RegistrationUser();
            user.FirstName = "";

            registrationFacade.RegistrateUser(registrationPage, user, this.driver);

            Assert.AreEqual("* This field is required", registrationPage.NamesErrorMessage.Text);
        }
    }
}
